#  tests for ligo-segments-1.0.0-py27h0c8e037_0 (this is a generated file);
print('===== testing package: ligo-segments-1.0.0-py27h0c8e037_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
from ligo import segments
assert (segments.segment(1, 2) +
        segments.segment(2, 3)) == segments.segment(1, 3)
#  --- run_test.py (end) ---

print('===== ligo-segments-1.0.0-py27h0c8e037_0 OK =====');
print("import: 'ligo.segments'")
import ligo.segments

